@@ -1,149 +1,155 @@
 var group__pw__keys =
 [
+    [ "keys.h", "src_2pipewire_2keys_8h.html", null ],
+    [ "PW_KEY_PROTOCOL", "group__pw__keys.html#ga75a6c78ce2de6d3dc5ed23abecdbc3bd", null ],
     [ "PW_KEY_ACCESS", "group__pw__keys.html#gad1bfca30c613b28723527132429bb342", null ],
-    [ "PW_KEY_APP_ICON", "group__pw__keys.html#ga91ffcff4f7a88575416d6aecbcff12e4", null ],
-    [ "PW_KEY_APP_ICON_NAME", "group__pw__keys.html#ga4e2766cf97b0c413b31daffd06194fb8", null ],
-    [ "PW_KEY_APP_ID", "group__pw__keys.html#ga7e7975fdc1d4879492d18bd5737fc7d7", null ],
-    [ "PW_KEY_APP_LANGUAGE", "group__pw__keys.html#ga1a435b1fed956236009f28357f69a11c", null ],
-    [ "PW_KEY_APP_NAME", "group__pw__keys.html#ga56fa277cca24072d0208f0ada2e8af02", null ],
-    [ "PW_KEY_APP_PROCESS_BINARY", "group__pw__keys.html#ga21aeba14e1488c5133af73d8857f2c4b", null ],
-    [ "PW_KEY_APP_PROCESS_HOST", "group__pw__keys.html#ga10b428d9bce530cad8fd247157ae2dc0", null ],
-    [ "PW_KEY_APP_PROCESS_ID", "group__pw__keys.html#gaad182b8b5d38fc6083d15b2c43e00e83", null ],
-    [ "PW_KEY_APP_PROCESS_MACHINE_ID", "group__pw__keys.html#ga1c5aadbbcd440e874a9b86c4ebd3445f", null ],
-    [ "PW_KEY_APP_PROCESS_SESSION_ID", "group__pw__keys.html#gaedf51309856ddd63ceb49dd66f047f30", null ],
-    [ "PW_KEY_APP_PROCESS_USER", "group__pw__keys.html#ga6ce71220f1c5262d51adfcc8b9648b69", null ],
-    [ "PW_KEY_APP_VERSION", "group__pw__keys.html#gaba46167b2135bb7862a8c92b6a8066ab", null ],
-    [ "PW_KEY_AUDIO_CHANNEL", "group__pw__keys.html#gad1330d4bd54022740c64b1b7b0cc357e", null ],
-    [ "PW_KEY_AUDIO_CHANNELS", "group__pw__keys.html#ga7f63a5688e90b4d78e8db0c7a18bd959", null ],
-    [ "PW_KEY_AUDIO_FORMAT", "group__pw__keys.html#ga0b13a2631ffb67076f67105d1ca347d6", null ],
-    [ "PW_KEY_AUDIO_RATE", "group__pw__keys.html#gaf4643e961de004488943e2ab0322ac4c", null ],
     [ "PW_KEY_CLIENT_ACCESS", "group__pw__keys.html#ga550a0954601e7bf139955115f4b1c030", null ],
-    [ "PW_KEY_CLIENT_API", "group__pw__keys.html#gad38809401a347afdefdefc12b9066e10", null ],
-    [ "PW_KEY_CLIENT_ID", "group__pw__keys.html#ga40cda23f85c981d1fc72e452f0972c0b", null ],
-    [ "PW_KEY_CLIENT_NAME", "group__pw__keys.html#ga53bbec2813b8e4f108d1d50596e0669b", null ],
-    [ "PW_KEY_CONFIG_NAME", "group__pw__keys.html#gaa2b0c7062965986d9d8dbadf553eb6ba", null ],
+    [ "PW_KEY_SEC_PID", "group__pw__keys.html#ga3273f4c970bf0c85f1eb220d368ea444", null ],
+    [ "PW_KEY_SEC_UID", "group__pw__keys.html#gad6000734888b498669ad7aebcee155eb", null ],
+    [ "PW_KEY_SEC_GID", "group__pw__keys.html#ga6abeb07b483a60e05f60224f7a5aae34", null ],
+    [ "PW_KEY_SEC_LABEL", "group__pw__keys.html#ga9cde0fd069af370dd80ad3deac5ee053", null ],
+    [ "PW_KEY_LIBRARY_NAME_SYSTEM", "group__pw__keys.html#gada76163a82aae28e7563c6c28eddc5ea", null ],
+    [ "PW_KEY_LIBRARY_NAME_LOOP", "group__pw__keys.html#ga62381a633016e0f980878eaa018ef429", null ],
+    [ "PW_KEY_LIBRARY_NAME_DBUS", "group__pw__keys.html#ga32748e803174c4983e3f5378fcbe0e87", null ],
+    [ "PW_KEY_OBJECT_PATH", "group__pw__keys.html#gaf7bfe4ca43d361fe707d51c4b4590423", null ],
+    [ "PW_KEY_OBJECT_ID", "group__pw__keys.html#gaaa13a0c747a64ff4f80c68f383e6f479", null ],
+    [ "PW_KEY_OBJECT_LINGER", "group__pw__keys.html#ga3d5bd6f00b3c9a8d89e42aa6c3f8cb58", null ],
+    [ "PW_KEY_OBJECT_REGISTER", "group__pw__keys.html#ga615dfda75e0fc56ae2f2f18a6acdae9c", null ],
     [ "PW_KEY_CONFIG_PREFIX", "group__pw__keys.html#ga547e340cc89d32b3c2378ec365c23c6c", null ],
+    [ "PW_KEY_CONFIG_NAME", "group__pw__keys.html#gaa2b0c7062965986d9d8dbadf553eb6ba", null ],
     [ "PW_KEY_CONTEXT_PROFILE_MODULES", "group__pw__keys.html#ga2b3f6a3b030fd27d17482e601c22be3b", null ],
+    [ "PW_KEY_USER_NAME", "group__pw__keys.html#ga42bba61b82c004dd909c1796633e936b", null ],
+    [ "PW_KEY_HOST_NAME", "group__pw__keys.html#ga9530cacf53a11083543fc8b0076d8b4b", null ],
+    [ "PW_KEY_CORE_NAME", "group__pw__keys.html#ga7d8bfd1e173bfbb0360b7a59bd2ec68a", null ],
+    [ "PW_KEY_CORE_VERSION", "group__pw__keys.html#gadaf914599e9ddeab31f925204323f678", null ],
     [ "PW_KEY_CORE_DAEMON", "group__pw__keys.html#ga8226b0005fed53b77740e919947f6e60", null ],
     [ "PW_KEY_CORE_ID", "group__pw__keys.html#ga01502d8ebbf130bdc9bdbc847da9202a", null ],
     [ "PW_KEY_CORE_MONITORS", "group__pw__keys.html#ga1fcadd4d03343c8f5737c00f4900404e", null ],
-    [ "PW_KEY_CORE_NAME", "group__pw__keys.html#ga7d8bfd1e173bfbb0360b7a59bd2ec68a", null ],
-    [ "PW_KEY_CORE_VERSION", "group__pw__keys.html#gadaf914599e9ddeab31f925204323f678", null ],
-    [ "PW_KEY_CPU_CORES", "group__pw__keys.html#gaa11bdd266a759598aaab9aac3c6f2a3a", null ],
     [ "PW_KEY_CPU_MAX_ALIGN", "group__pw__keys.html#ga06b47804dd060e946c700c96ba46aa22", null ],
-    [ "PW_KEY_DEVICE_API", "group__pw__keys.html#ga1ae6cfa4f3af67155c58f5f0398e8c56", null ],
-    [ "PW_KEY_DEVICE_BUS", "group__pw__keys.html#gac1cc4afb3e028b4d00231d615705adce", null ],
-    [ "PW_KEY_DEVICE_BUS_PATH", "group__pw__keys.html#gad853c0be569ab7bc329486573016a600", null ],
-    [ "PW_KEY_DEVICE_CACHE_PARAMS", "group__pw__keys.html#ga7bab8d7cd60e1866868124d28b87f43f", null ],
-    [ "PW_KEY_DEVICE_CLASS", "group__pw__keys.html#ga4790b6248f443648211d05573db3ac77", null ],
-    [ "PW_KEY_DEVICE_DESCRIPTION", "group__pw__keys.html#ga66aff2e97b93c3b4c029de74f0233373", null ],
-    [ "PW_KEY_DEVICE_FORM_FACTOR", "group__pw__keys.html#ga2ce5cc947b2519113b1d96b4f599eae3", null ],
-    [ "PW_KEY_DEVICE_ICON", "group__pw__keys.html#gae735cebef63f5368aec0d1859890c5cb", null ],
-    [ "PW_KEY_DEVICE_ICON_NAME", "group__pw__keys.html#ga2a53446671230c87420a0edd859e70c4", null ],
-    [ "PW_KEY_DEVICE_ID", "group__pw__keys.html#ga0b1f97dbee8170ef4b6e972fac51dd73", null ],
-    [ "PW_KEY_DEVICE_INTENDED_ROLES", "group__pw__keys.html#gada09ee1ffbf8eb6eaf8bb5f0431fbccf", null ],
-    [ "PW_KEY_DEVICE_NAME", "group__pw__keys.html#ga3815f163f7283a2d979daf59acb204e2", null ],
-    [ "PW_KEY_DEVICE_NICK", "group__pw__keys.html#gafe595c32416d6f09ff02ceb3d91517fe", null ],
-    [ "PW_KEY_DEVICE_PLUGGED", "group__pw__keys.html#ga0f5e212dc11f074ea26ec962050242d9", null ],
-    [ "PW_KEY_DEVICE_PRODUCT_ID", "group__pw__keys.html#ga4e33abd756479b380e6413a54ce66d9c", null ],
-    [ "PW_KEY_DEVICE_PRODUCT_NAME", "group__pw__keys.html#ga02187c666af78ce29dc10af967233709", null ],
-    [ "PW_KEY_DEVICE_SERIAL", "group__pw__keys.html#ga355da8fad4633bc22ddac10620451672", null ],
-    [ "PW_KEY_DEVICE_STRING", "group__pw__keys.html#gadeb9ac2f463b5163d363a13a03c9dde1", null ],
-    [ "PW_KEY_DEVICE_SUBSYSTEM", "group__pw__keys.html#gaae4d17260ca60c2ab5e2c8d32b989d67", null ],
-    [ "PW_KEY_DEVICE_VENDOR_ID", "group__pw__keys.html#gab0c9eba65b9611e85e0304b49f58739e", null ],
-    [ "PW_KEY_DEVICE_VENDOR_NAME", "group__pw__keys.html#gaee10eee4b6b4dc090110939e78adbc10", null ],
-    [ "PW_KEY_FACTORY_ID", "group__pw__keys.html#ga57e4e4edbcaf5d9420a24f033cf48f3d", null ],
-    [ "PW_KEY_FACTORY_NAME", "group__pw__keys.html#ga574c03c1c69ee214f3ef156903226bac", null ],
-    [ "PW_KEY_FACTORY_TYPE_NAME", "group__pw__keys.html#ga2094ae2785d311a4b58da7357ec257ed", null ],
-    [ "PW_KEY_FACTORY_TYPE_VERSION", "group__pw__keys.html#ga897eec1867a8fc40db2526f7fed9b2db", null ],
-    [ "PW_KEY_FACTORY_USAGE", "group__pw__keys.html#gab63750b3248313ac7ca19b93feedeb9b", null ],
-    [ "PW_KEY_FORMAT_DSP", "group__pw__keys.html#gaecb23469e678c55d7c0f3b6ebe180abb", null ],
-    [ "PW_KEY_HOST_NAME", "group__pw__keys.html#ga9530cacf53a11083543fc8b0076d8b4b", null ],
-    [ "PW_KEY_LIBRARY_NAME_DBUS", "group__pw__keys.html#ga32748e803174c4983e3f5378fcbe0e87", null ],
-    [ "PW_KEY_LIBRARY_NAME_LOOP", "group__pw__keys.html#ga62381a633016e0f980878eaa018ef429", null ],
-    [ "PW_KEY_LIBRARY_NAME_SYSTEM", "group__pw__keys.html#gada76163a82aae28e7563c6c28eddc5ea", null ],
-    [ "PW_KEY_LINK_FEEDBACK", "group__pw__keys.html#ga89d9bba5f43373e1800fed52424575ee", null ],
+    [ "PW_KEY_CPU_CORES", "group__pw__keys.html#gaa11bdd266a759598aaab9aac3c6f2a3a", null ],
+    [ "PW_KEY_PRIORITY_SESSION", "group__pw__keys.html#gaeb72e3878b35a65f02163535ad274408", null ],
+    [ "PW_KEY_PRIORITY_DRIVER", "group__pw__keys.html#gaf0a8b16bba9dde55e5b8ba018b4b5ceb", null ],
+    [ "PW_KEY_REMOTE_NAME", "group__pw__keys.html#ga86dd4aa9894e3d6deb9570988e37f6ca", null ],
+    [ "PW_KEY_REMOTE_INTENTION", "group__pw__keys.html#gaff405f056c4afbeb87df6f663178b993", null ],
+    [ "PW_KEY_APP_NAME", "group__pw__keys.html#ga56fa277cca24072d0208f0ada2e8af02", null ],
+    [ "PW_KEY_APP_ID", "group__pw__keys.html#ga7e7975fdc1d4879492d18bd5737fc7d7", null ],
+    [ "PW_KEY_APP_VERSION", "group__pw__keys.html#gaba46167b2135bb7862a8c92b6a8066ab", null ],
+    [ "PW_KEY_APP_ICON", "group__pw__keys.html#ga91ffcff4f7a88575416d6aecbcff12e4", null ],
+    [ "PW_KEY_APP_ICON_NAME", "group__pw__keys.html#ga4e2766cf97b0c413b31daffd06194fb8", null ],
+    [ "PW_KEY_APP_LANGUAGE", "group__pw__keys.html#ga1a435b1fed956236009f28357f69a11c", null ],
+    [ "PW_KEY_APP_PROCESS_ID", "group__pw__keys.html#gaad182b8b5d38fc6083d15b2c43e00e83", null ],
+    [ "PW_KEY_APP_PROCESS_BINARY", "group__pw__keys.html#ga21aeba14e1488c5133af73d8857f2c4b", null ],
+    [ "PW_KEY_APP_PROCESS_USER", "group__pw__keys.html#ga6ce71220f1c5262d51adfcc8b9648b69", null ],
+    [ "PW_KEY_APP_PROCESS_HOST", "group__pw__keys.html#ga10b428d9bce530cad8fd247157ae2dc0", null ],
+    [ "PW_KEY_APP_PROCESS_MACHINE_ID", "group__pw__keys.html#ga1c5aadbbcd440e874a9b86c4ebd3445f", null ],
+    [ "PW_KEY_APP_PROCESS_SESSION_ID", "group__pw__keys.html#gaedf51309856ddd63ceb49dd66f047f30", null ],
+    [ "PW_KEY_WINDOW_X11_DISPLAY", "group__pw__keys.html#gac21702d9ef1b7b6772303f4681e854a1", null ],
+    [ "PW_KEY_CLIENT_ID", "group__pw__keys.html#ga40cda23f85c981d1fc72e452f0972c0b", null ],
+    [ "PW_KEY_CLIENT_NAME", "group__pw__keys.html#ga53bbec2813b8e4f108d1d50596e0669b", null ],
+    [ "PW_KEY_CLIENT_API", "group__pw__keys.html#gad38809401a347afdefdefc12b9066e10", null ],
+    [ "PW_KEY_NODE_ID", "group__pw__keys.html#gaf3bf787a5d2b9e035d3ddfdfe848d810", null ],
+    [ "PW_KEY_NODE_NAME", "group__pw__keys.html#gaaa6e55cb44dbfe8af1a9e8531abe6f09", null ],
+    [ "PW_KEY_NODE_NICK", "group__pw__keys.html#gab54f33c6bfc0125599328b198ae81d06", null ],
+    [ "PW_KEY_NODE_DESCRIPTION", "group__pw__keys.html#ga4d4e1af1a950aafe7b4184a89fa4e016", null ],
+    [ "PW_KEY_NODE_PLUGGED", "group__pw__keys.html#ga36edd8da67e859b5b7c6ab425f4f9e49", null ],
+    [ "PW_KEY_NODE_SESSION", "group__pw__keys.html#ga457ecf62c9dcb4a1f5719bc74fbb0183", null ],
+    [ "PW_KEY_NODE_GROUP", "group__pw__keys.html#ga5b8ea75d1a6f9a1d0d0e60e60eeae5a8", null ],
+    [ "PW_KEY_NODE_EXCLUSIVE", "group__pw__keys.html#gacc9bbcbe9fc948df2fec4592640cd39c", null ],
+    [ "PW_KEY_NODE_AUTOCONNECT", "group__pw__keys.html#ga677b0938b4f1d2d52326c64b4b90eb8e", null ],
+    [ "PW_KEY_NODE_TARGET", "group__pw__keys.html#ga33441b02b8e14e14451272c2b497a5c9", null ],
+    [ "PW_KEY_NODE_LATENCY", "group__pw__keys.html#ga6d08c36bb4d3bcae49e822023a8089e2", null ],
+    [ "PW_KEY_NODE_MAX_LATENCY", "group__pw__keys.html#gaad5f9ff2318f5ff7156b81e4efa4b9fc", null ],
+    [ "PW_KEY_NODE_LOCK_QUANTUM", "group__pw__keys.html#ga7e12dd6c9dec4a345c8a2a62f138b5bf", null ],
+    [ "PW_KEY_NODE_RATE", "group__pw__keys.html#ga1acad010d64de1a1d5225a23f5409d93", null ],
+    [ "PW_KEY_NODE_LOCK_RATE", "group__pw__keys.html#ga459ef9c4251e8d02af6e52ab24d99fc1", null ],
+    [ "PW_KEY_NODE_DONT_RECONNECT", "group__pw__keys.html#ga02774290763120baf89042785522c0c2", null ],
+    [ "PW_KEY_NODE_ALWAYS_PROCESS", "group__pw__keys.html#ga832d4e7fcc412f53aea49186c6ff2c8b", null ],
+    [ "PW_KEY_NODE_WANT_DRIVER", "group__pw__keys.html#ga44a2c0b545bb924fcd5e93f0ce0b126d", null ],
+    [ "PW_KEY_NODE_PAUSE_ON_IDLE", "group__pw__keys.html#ga0fb0fbf1691bb6972434b61706c3217a", null ],
+    [ "PW_KEY_NODE_CACHE_PARAMS", "group__pw__keys.html#ga6a9a361b575634ed2b4040eefbd9799a", null ],
+    [ "PW_KEY_NODE_DRIVER", "group__pw__keys.html#gac760a7d13f161fcc86e964ad23399180", null ],
+    [ "PW_KEY_NODE_STREAM", "group__pw__keys.html#ga8ff654b149404ba9e46f02e376cf9dcc", null ],
+    [ "PW_KEY_NODE_VIRTUAL", "group__pw__keys.html#gad47c9bd7ac42e326f5879cac7b73df6f", null ],
+    [ "PW_KEY_NODE_PASSIVE", "group__pw__keys.html#ga79f57786e98b76caf777f856ce26092b", null ],
+    [ "PW_KEY_NODE_LINK_GROUP", "group__pw__keys.html#ga30bf1394ef6129573c44fea7d3af880e", null ],
+    [ "PW_KEY_NODE_NETWORK", "group__pw__keys.html#ga7cc45df5bd241b9bb924802082490449", null ],
+    [ "PW_KEY_PORT_ID", "group__pw__keys.html#ga94975808271e28be225a6fd6d7957762", null ],
+    [ "PW_KEY_PORT_NAME", "group__pw__keys.html#ga086fc9bb9864325037b0bd2310816034", null ],
+    [ "PW_KEY_PORT_DIRECTION", "group__pw__keys.html#ga4a25213dfcf1d7b7ded06ed9284f1a5f", null ],
+    [ "PW_KEY_PORT_ALIAS", "group__pw__keys.html#gafa03a2ea34407e692ddc35bb1f200c59", null ],
+    [ "PW_KEY_PORT_PHYSICAL", "group__pw__keys.html#ga42bac0319021f95809991bf90ff5f1c5", null ],
+    [ "PW_KEY_PORT_TERMINAL", "group__pw__keys.html#ga53f5727e8c728c0398320b5191bb934c", null ],
+    [ "PW_KEY_PORT_CONTROL", "group__pw__keys.html#gaf8e40c7f0a99f019f9b3b8187b96f8b0", null ],
+    [ "PW_KEY_PORT_MONITOR", "group__pw__keys.html#ga52f311c1f1005fda30a47a3b5fc19a77", null ],
+    [ "PW_KEY_PORT_CACHE_PARAMS", "group__pw__keys.html#ga2e7814e10b6e027a7808d17ac49f2922", null ],
+    [ "PW_KEY_PORT_EXTRA", "group__pw__keys.html#gab4a0aa1d5cff227f1fb19253c0ad221a", null ],
     [ "PW_KEY_LINK_ID", "group__pw__keys.html#ga2adca834d1bf86f9bb4c3d52af9460e8", null ],
     [ "PW_KEY_LINK_INPUT_NODE", "group__pw__keys.html#ga8bcf374cc8d1cf2c23060479d484c4c8", null ],
     [ "PW_KEY_LINK_INPUT_PORT", "group__pw__keys.html#gae327718323a22392d489db85ad83ab8f", null ],
     [ "PW_KEY_LINK_OUTPUT_NODE", "group__pw__keys.html#gaaa5cf742d2c5bfee35f18392ddc3ca9e", null ],
     [ "PW_KEY_LINK_OUTPUT_PORT", "group__pw__keys.html#ga4976c4bc1a9d0119617d02fae557e108", null ],
     [ "PW_KEY_LINK_PASSIVE", "group__pw__keys.html#gafcd3d133168b9353c89c1c5f2de6954e", null ],
-    [ "PW_KEY_MEDIA_ARTIST", "group__pw__keys.html#ga5239e21cdcdd48b4dc147305df1cb742", null ],
-    [ "PW_KEY_MEDIA_CATEGORY", "group__pw__keys.html#gad58dc457d6b068c7ae086b6792824404", null ],
-    [ "PW_KEY_MEDIA_CLASS", "group__pw__keys.html#gaed255c860a65813289cb4c4620243da6", null ],
-    [ "PW_KEY_MEDIA_COMMENT", "group__pw__keys.html#gae0e0edc267b24e27054f72f899cb2123", null ],
-    [ "PW_KEY_MEDIA_COPYRIGHT", "group__pw__keys.html#ga377a7240f82837f1c861976faf4240af", null ],
-    [ "PW_KEY_MEDIA_DATE", "group__pw__keys.html#ga920ad1d3f16b5fe42e001aab2af08680", null ],
-    [ "PW_KEY_MEDIA_FILENAME", "group__pw__keys.html#ga0823daaf814cb12aca70c024f76eaf0b", null ],
-    [ "PW_KEY_MEDIA_FORMAT", "group__pw__keys.html#ga5fcd76f87ed122633f0a90ac05aae123", null ],
-    [ "PW_KEY_MEDIA_ICON", "group__pw__keys.html#ga49cb5fe34980f268f7bb844f54de72f5", null ],
-    [ "PW_KEY_MEDIA_ICON_NAME", "group__pw__keys.html#gad7fe1ca68b65df33c09b8d14cfd708b0", null ],
-    [ "PW_KEY_MEDIA_LANGUAGE", "group__pw__keys.html#ga308a6720f63b611d74666c4dfc6dbe7d", null ],
-    [ "PW_KEY_MEDIA_NAME", "group__pw__keys.html#gac8cc358cf31f66cde84ed87a9a2fb2e7", null ],
-    [ "PW_KEY_MEDIA_ROLE", "group__pw__keys.html#ga7e7dcf769f9e253b0e3cde6534feed69", null ],
-    [ "PW_KEY_MEDIA_SOFTWARE", "group__pw__keys.html#ga6cceecd3d45dc787cddaefc7c3c5de53", null ],
-    [ "PW_KEY_MEDIA_TITLE", "group__pw__keys.html#ga6d930a117ae86e23154fbfdcca42cab8", null ],
-    [ "PW_KEY_MEDIA_TYPE", "group__pw__keys.html#ga1bb5e1cae8d27cc995923266024c0ed5", null ],
-    [ "PW_KEY_MODULE_AUTHOR", "group__pw__keys.html#ga7b74eb5c78b28b8346df16e7d66487d1", null ],
-    [ "PW_KEY_MODULE_DESCRIPTION", "group__pw__keys.html#gabfbbb750dca1b2cbd8aef676e6f3b1f3", null ],
+    [ "PW_KEY_LINK_FEEDBACK", "group__pw__keys.html#ga89d9bba5f43373e1800fed52424575ee", null ],
+    [ "PW_KEY_DEVICE_ID", "group__pw__keys.html#ga0b1f97dbee8170ef4b6e972fac51dd73", null ],
+    [ "PW_KEY_DEVICE_NAME", "group__pw__keys.html#ga3815f163f7283a2d979daf59acb204e2", null ],
+    [ "PW_KEY_DEVICE_PLUGGED", "group__pw__keys.html#ga0f5e212dc11f074ea26ec962050242d9", null ],
+    [ "PW_KEY_DEVICE_NICK", "group__pw__keys.html#gafe595c32416d6f09ff02ceb3d91517fe", null ],
+    [ "PW_KEY_DEVICE_STRING", "group__pw__keys.html#gadeb9ac2f463b5163d363a13a03c9dde1", null ],
+    [ "PW_KEY_DEVICE_API", "group__pw__keys.html#ga1ae6cfa4f3af67155c58f5f0398e8c56", null ],
+    [ "PW_KEY_DEVICE_DESCRIPTION", "group__pw__keys.html#ga66aff2e97b93c3b4c029de74f0233373", null ],
+    [ "PW_KEY_DEVICE_BUS_PATH", "group__pw__keys.html#gad853c0be569ab7bc329486573016a600", null ],
+    [ "PW_KEY_DEVICE_SERIAL", "group__pw__keys.html#ga355da8fad4633bc22ddac10620451672", null ],
+    [ "PW_KEY_DEVICE_VENDOR_ID", "group__pw__keys.html#gab0c9eba65b9611e85e0304b49f58739e", null ],
+    [ "PW_KEY_DEVICE_VENDOR_NAME", "group__pw__keys.html#gaee10eee4b6b4dc090110939e78adbc10", null ],
+    [ "PW_KEY_DEVICE_PRODUCT_ID", "group__pw__keys.html#ga4e33abd756479b380e6413a54ce66d9c", null ],
+    [ "PW_KEY_DEVICE_PRODUCT_NAME", "group__pw__keys.html#ga02187c666af78ce29dc10af967233709", null ],
+    [ "PW_KEY_DEVICE_CLASS", "group__pw__keys.html#ga4790b6248f443648211d05573db3ac77", null ],
+    [ "PW_KEY_DEVICE_FORM_FACTOR", "group__pw__keys.html#ga2ce5cc947b2519113b1d96b4f599eae3", null ],
+    [ "PW_KEY_DEVICE_BUS", "group__pw__keys.html#gac1cc4afb3e028b4d00231d615705adce", null ],
+    [ "PW_KEY_DEVICE_SUBSYSTEM", "group__pw__keys.html#gaae4d17260ca60c2ab5e2c8d32b989d67", null ],
+    [ "PW_KEY_DEVICE_ICON", "group__pw__keys.html#gae735cebef63f5368aec0d1859890c5cb", null ],
+    [ "PW_KEY_DEVICE_ICON_NAME", "group__pw__keys.html#ga2a53446671230c87420a0edd859e70c4", null ],
+    [ "PW_KEY_DEVICE_INTENDED_ROLES", "group__pw__keys.html#gada09ee1ffbf8eb6eaf8bb5f0431fbccf", null ],
+    [ "PW_KEY_DEVICE_CACHE_PARAMS", "group__pw__keys.html#ga7bab8d7cd60e1866868124d28b87f43f", null ],
     [ "PW_KEY_MODULE_ID", "group__pw__keys.html#gabe4f427fb9ecb27d29c2567243ce18e7", null ],
     [ "PW_KEY_MODULE_NAME", "group__pw__keys.html#gab36a79eff93ca96a84fc38c7aedb4ecf", null ],
+    [ "PW_KEY_MODULE_AUTHOR", "group__pw__keys.html#ga7b74eb5c78b28b8346df16e7d66487d1", null ],
+    [ "PW_KEY_MODULE_DESCRIPTION", "group__pw__keys.html#gabfbbb750dca1b2cbd8aef676e6f3b1f3", null ],
     [ "PW_KEY_MODULE_USAGE", "group__pw__keys.html#ga06f0aa2f06667a7596322689acf3b1b7", null ],
     [ "PW_KEY_MODULE_VERSION", "group__pw__keys.html#ga18a9e0e59cd1a02e6c444edae293f887", null ],
-    [ "PW_KEY_NODE_ALWAYS_PROCESS", "group__pw__keys.html#ga832d4e7fcc412f53aea49186c6ff2c8b", null ],
-    [ "PW_KEY_NODE_AUTOCONNECT", "group__pw__keys.html#ga677b0938b4f1d2d52326c64b4b90eb8e", null ],
-    [ "PW_KEY_NODE_CACHE_PARAMS", "group__pw__keys.html#ga6a9a361b575634ed2b4040eefbd9799a", null ],
-    [ "PW_KEY_NODE_DESCRIPTION", "group__pw__keys.html#ga4d4e1af1a950aafe7b4184a89fa4e016", null ],
-    [ "PW_KEY_NODE_DONT_RECONNECT", "group__pw__keys.html#ga02774290763120baf89042785522c0c2", null ],
-    [ "PW_KEY_NODE_DRIVER", "group__pw__keys.html#gac760a7d13f161fcc86e964ad23399180", null ],
-    [ "PW_KEY_NODE_EXCLUSIVE", "group__pw__keys.html#gacc9bbcbe9fc948df2fec4592640cd39c", null ],
-    [ "PW_KEY_NODE_GROUP", "group__pw__keys.html#ga5b8ea75d1a6f9a1d0d0e60e60eeae5a8", null ],
-    [ "PW_KEY_NODE_ID", "group__pw__keys.html#gaf3bf787a5d2b9e035d3ddfdfe848d810", null ],
-    [ "PW_KEY_NODE_LATENCY", "group__pw__keys.html#ga6d08c36bb4d3bcae49e822023a8089e2", null ],
-    [ "PW_KEY_NODE_LINK_GROUP", "group__pw__keys.html#ga30bf1394ef6129573c44fea7d3af880e", null ],
-    [ "PW_KEY_NODE_MAX_LATENCY", "group__pw__keys.html#gaad5f9ff2318f5ff7156b81e4efa4b9fc", null ],
-    [ "PW_KEY_NODE_NAME", "group__pw__keys.html#gaaa6e55cb44dbfe8af1a9e8531abe6f09", null ],
-    [ "PW_KEY_NODE_NICK", "group__pw__keys.html#gab54f33c6bfc0125599328b198ae81d06", null ],
-    [ "PW_KEY_NODE_PASSIVE", "group__pw__keys.html#ga79f57786e98b76caf777f856ce26092b", null ],
-    [ "PW_KEY_NODE_PAUSE_ON_IDLE", "group__pw__keys.html#ga0fb0fbf1691bb6972434b61706c3217a", null ],
-    [ "PW_KEY_NODE_PLUGGED", "group__pw__keys.html#ga36edd8da67e859b5b7c6ab425f4f9e49", null ],
-    [ "PW_KEY_NODE_SESSION", "group__pw__keys.html#ga457ecf62c9dcb4a1f5719bc74fbb0183", null ],
-    [ "PW_KEY_NODE_STREAM", "group__pw__keys.html#ga8ff654b149404ba9e46f02e376cf9dcc", null ],
-    [ "PW_KEY_NODE_TARGET", "group__pw__keys.html#ga33441b02b8e14e14451272c2b497a5c9", null ],
-    [ "PW_KEY_NODE_VIRTUAL", "group__pw__keys.html#gad47c9bd7ac42e326f5879cac7b73df6f", null ],
-    [ "PW_KEY_OBJECT_ID", "group__pw__keys.html#gaaa13a0c747a64ff4f80c68f383e6f479", null ],
-    [ "PW_KEY_OBJECT_LINGER", "group__pw__keys.html#ga3d5bd6f00b3c9a8d89e42aa6c3f8cb58", null ],
-    [ "PW_KEY_OBJECT_PATH", "group__pw__keys.html#gaf7bfe4ca43d361fe707d51c4b4590423", null ],
-    [ "PW_KEY_OBJECT_REGISTER", "group__pw__keys.html#ga615dfda75e0fc56ae2f2f18a6acdae9c", null ],
-    [ "PW_KEY_PORT_ALIAS", "group__pw__keys.html#gafa03a2ea34407e692ddc35bb1f200c59", null ],
-    [ "PW_KEY_PORT_CACHE_PARAMS", "group__pw__keys.html#ga2e7814e10b6e027a7808d17ac49f2922", null ],
-    [ "PW_KEY_PORT_CONTROL", "group__pw__keys.html#gaf8e40c7f0a99f019f9b3b8187b96f8b0", null ],
-    [ "PW_KEY_PORT_DIRECTION", "group__pw__keys.html#ga4a25213dfcf1d7b7ded06ed9284f1a5f", null ],
-    [ "PW_KEY_PORT_EXTRA", "group__pw__keys.html#gab4a0aa1d5cff227f1fb19253c0ad221a", null ],
-    [ "PW_KEY_PORT_ID", "group__pw__keys.html#ga94975808271e28be225a6fd6d7957762", null ],
-    [ "PW_KEY_PORT_MONITOR", "group__pw__keys.html#ga52f311c1f1005fda30a47a3b5fc19a77", null ],
-    [ "PW_KEY_PORT_NAME", "group__pw__keys.html#ga086fc9bb9864325037b0bd2310816034", null ],
-    [ "PW_KEY_PORT_PHYSICAL", "group__pw__keys.html#ga42bac0319021f95809991bf90ff5f1c5", null ],
-    [ "PW_KEY_PORT_TERMINAL", "group__pw__keys.html#ga53f5727e8c728c0398320b5191bb934c", null ],
-    [ "PW_KEY_PRIORITY_DRIVER", "group__pw__keys.html#gaf0a8b16bba9dde55e5b8ba018b4b5ceb", null ],
-    [ "PW_KEY_PRIORITY_SESSION", "group__pw__keys.html#gaeb72e3878b35a65f02163535ad274408", null ],
-    [ "PW_KEY_PROTOCOL", "group__pw__keys.html#ga75a6c78ce2de6d3dc5ed23abecdbc3bd", null ],
-    [ "PW_KEY_REMOTE_INTENTION", "group__pw__keys.html#gaff405f056c4afbeb87df6f663178b993", null ],
-    [ "PW_KEY_REMOTE_NAME", "group__pw__keys.html#ga86dd4aa9894e3d6deb9570988e37f6ca", null ],
-    [ "PW_KEY_SEC_GID", "group__pw__keys.html#ga6abeb07b483a60e05f60224f7a5aae34", null ],
-    [ "PW_KEY_SEC_LABEL", "group__pw__keys.html#ga9cde0fd069af370dd80ad3deac5ee053", null ],
-    [ "PW_KEY_SEC_PID", "group__pw__keys.html#ga3273f4c970bf0c85f1eb220d368ea444", null ],
-    [ "PW_KEY_SEC_UID", "group__pw__keys.html#gad6000734888b498669ad7aebcee155eb", null ],
-    [ "PW_KEY_STREAM_CAPTURE_SINK", "group__pw__keys.html#ga1ac41df86c2b03ef693864d48d80f735", null ],
-    [ "PW_KEY_STREAM_DONT_REMIX", "group__pw__keys.html#ga79843e403121d8dda275d869c770d3f2", null ],
+    [ "PW_KEY_FACTORY_ID", "group__pw__keys.html#ga57e4e4edbcaf5d9420a24f033cf48f3d", null ],
+    [ "PW_KEY_FACTORY_NAME", "group__pw__keys.html#ga574c03c1c69ee214f3ef156903226bac", null ],
+    [ "PW_KEY_FACTORY_USAGE", "group__pw__keys.html#gab63750b3248313ac7ca19b93feedeb9b", null ],
+    [ "PW_KEY_FACTORY_TYPE_NAME", "group__pw__keys.html#ga2094ae2785d311a4b58da7357ec257ed", null ],
+    [ "PW_KEY_FACTORY_TYPE_VERSION", "group__pw__keys.html#ga897eec1867a8fc40db2526f7fed9b2db", null ],
     [ "PW_KEY_STREAM_IS_LIVE", "group__pw__keys.html#gafc94345e17e428e4816adf8eb0bcb993", null ],
-    [ "PW_KEY_STREAM_LATENCY_MAX", "group__pw__keys.html#ga2d0601eb11704dc85da950b5188a4ad3", null ],
     [ "PW_KEY_STREAM_LATENCY_MIN", "group__pw__keys.html#ga91d57a3b42dc55028dd49755716db901", null ],
+    [ "PW_KEY_STREAM_LATENCY_MAX", "group__pw__keys.html#ga2d0601eb11704dc85da950b5188a4ad3", null ],
     [ "PW_KEY_STREAM_MONITOR", "group__pw__keys.html#ga0e1b45ffe5365ae023676fab61f53764", null ],
-    [ "PW_KEY_USER_NAME", "group__pw__keys.html#ga42bba61b82c004dd909c1796633e936b", null ],
-    [ "PW_KEY_VIDEO_FORMAT", "group__pw__keys.html#ga38e8da2c19e9cd1acf5823865f6e9742", null ],
+    [ "PW_KEY_STREAM_DONT_REMIX", "group__pw__keys.html#ga79843e403121d8dda275d869c770d3f2", null ],
+    [ "PW_KEY_STREAM_CAPTURE_SINK", "group__pw__keys.html#ga1ac41df86c2b03ef693864d48d80f735", null ],
+    [ "PW_KEY_MEDIA_TYPE", "group__pw__keys.html#ga1bb5e1cae8d27cc995923266024c0ed5", null ],
+    [ "PW_KEY_MEDIA_CATEGORY", "group__pw__keys.html#gad58dc457d6b068c7ae086b6792824404", null ],
+    [ "PW_KEY_MEDIA_ROLE", "group__pw__keys.html#ga7e7dcf769f9e253b0e3cde6534feed69", null ],
+    [ "PW_KEY_MEDIA_CLASS", "group__pw__keys.html#gaed255c860a65813289cb4c4620243da6", null ],
+    [ "PW_KEY_MEDIA_NAME", "group__pw__keys.html#gac8cc358cf31f66cde84ed87a9a2fb2e7", null ],
+    [ "PW_KEY_MEDIA_TITLE", "group__pw__keys.html#ga6d930a117ae86e23154fbfdcca42cab8", null ],
+    [ "PW_KEY_MEDIA_ARTIST", "group__pw__keys.html#ga5239e21cdcdd48b4dc147305df1cb742", null ],
+    [ "PW_KEY_MEDIA_COPYRIGHT", "group__pw__keys.html#ga377a7240f82837f1c861976faf4240af", null ],
+    [ "PW_KEY_MEDIA_SOFTWARE", "group__pw__keys.html#ga6cceecd3d45dc787cddaefc7c3c5de53", null ],
+    [ "PW_KEY_MEDIA_LANGUAGE", "group__pw__keys.html#ga308a6720f63b611d74666c4dfc6dbe7d", null ],
+    [ "PW_KEY_MEDIA_FILENAME", "group__pw__keys.html#ga0823daaf814cb12aca70c024f76eaf0b", null ],
+    [ "PW_KEY_MEDIA_ICON", "group__pw__keys.html#ga49cb5fe34980f268f7bb844f54de72f5", null ],
+    [ "PW_KEY_MEDIA_ICON_NAME", "group__pw__keys.html#gad7fe1ca68b65df33c09b8d14cfd708b0", null ],
+    [ "PW_KEY_MEDIA_COMMENT", "group__pw__keys.html#gae0e0edc267b24e27054f72f899cb2123", null ],
+    [ "PW_KEY_MEDIA_DATE", "group__pw__keys.html#ga920ad1d3f16b5fe42e001aab2af08680", null ],
+    [ "PW_KEY_MEDIA_FORMAT", "group__pw__keys.html#ga5fcd76f87ed122633f0a90ac05aae123", null ],
+    [ "PW_KEY_FORMAT_DSP", "group__pw__keys.html#gaecb23469e678c55d7c0f3b6ebe180abb", null ],
+    [ "PW_KEY_AUDIO_CHANNEL", "group__pw__keys.html#gad1330d4bd54022740c64b1b7b0cc357e", null ],
+    [ "PW_KEY_AUDIO_RATE", "group__pw__keys.html#gaf4643e961de004488943e2ab0322ac4c", null ],
+    [ "PW_KEY_AUDIO_CHANNELS", "group__pw__keys.html#ga7f63a5688e90b4d78e8db0c7a18bd959", null ],
+    [ "PW_KEY_AUDIO_FORMAT", "group__pw__keys.html#ga0b13a2631ffb67076f67105d1ca347d6", null ],
     [ "PW_KEY_VIDEO_RATE", "group__pw__keys.html#gac353c9d9c3ed50ea98806f63f09f9456", null ],
-    [ "PW_KEY_VIDEO_SIZE", "group__pw__keys.html#gacc4d098e86d0be0bfe469604c07f4009", null ],
-    [ "PW_KEY_WINDOW_X11_DISPLAY", "group__pw__keys.html#gac21702d9ef1b7b6772303f4681e854a1", null ]
+    [ "PW_KEY_VIDEO_FORMAT", "group__pw__keys.html#ga38e8da2c19e9cd1acf5823865f6e9742", null ],
+    [ "PW_KEY_VIDEO_SIZE", "group__pw__keys.html#gacc4d098e86d0be0bfe469604c07f4009", null ]
 ];
\ No newline at end of file
