@@ -1,12 +1,12 @@
 var structpw__core__events =
 [
-    [ "add_mem", "structpw__core__events.html#aeaf261e59f9a58b5005418abf669271a", null ],
-    [ "bound_id", "structpw__core__events.html#ae99597f5f149475172942064d4911961", null ],
-    [ "done", "structpw__core__events.html#a6cf547297486e97c8969a1e08d837955", null ],
-    [ "error", "structpw__core__events.html#a55c28400675736b9365e711884f7a73b", null ],
+    [ "version", "structpw__core__events.html#a8d568483182f9bdd13d8d4acbac462b7", null ],
     [ "info", "structpw__core__events.html#aa6aae56a5a9eb60fd5a308bec837b0e6", null ],
+    [ "done", "structpw__core__events.html#a6cf547297486e97c8969a1e08d837955", null ],
     [ "ping", "structpw__core__events.html#ada596905cb8c963eee644a638b6628c2", null ],
+    [ "error", "structpw__core__events.html#a55c28400675736b9365e711884f7a73b", null ],
     [ "remove_id", "structpw__core__events.html#a9a930f32ad895727dffbeb6ae4c6e04d", null ],
-    [ "remove_mem", "structpw__core__events.html#a61cdc8ed8d593d66bdd7702d8294c063", null ],
-    [ "version", "structpw__core__events.html#a8d568483182f9bdd13d8d4acbac462b7", null ]
+    [ "bound_id", "structpw__core__events.html#ae99597f5f149475172942064d4911961", null ],
+    [ "add_mem", "structpw__core__events.html#aeaf261e59f9a58b5005418abf669271a", null ],
+    [ "remove_mem", "structpw__core__events.html#a61cdc8ed8d593d66bdd7702d8294c063", null ]
 ];
\ No newline at end of file
